# Generated by Django 3.0.7 on 2020-06-25 03:45

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('status_code', models.IntegerField(null=True)),
                ('reason_phrase', models.CharField(max_length=500, null=True)),
                ('metodo', models.CharField(max_length=30, null=True)),
                ('ip', models.GenericIPAddressField(null=True)),
                ('path', models.CharField(max_length=500, null=True)),
                ('session_key', models.CharField(max_length=200, null=True)),
                ('body', models.TextField(null=True)),
            ],
            options={
                'db_table': 'log',
            },
        ),
        migrations.CreateModel(
            name='Query',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('time', models.FloatField(null=True)),
                ('query', models.TextField(null=True)),
            ],
            options={
                'db_table': 'log_query',
            },
        ),
    ]
