# Generated by Django 3.0.7 on 2020-06-25 03:45

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('filial', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AddField(
            model_name='servico',
            name='usr_delete',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_servico_usr_delete', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='servico',
            name='usr_edicao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_servico_usr_edicao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='servico',
            name='usr_insercao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_servico_usr_insercao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='relacaoservicos',
            name='filial',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='filial.Filial'),
        ),
        migrations.AddField(
            model_name='relacaoservicos',
            name='servico',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='filial.Servico'),
        ),
        migrations.AddField(
            model_name='relacaoservicos',
            name='usr_delete',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_relacaoservicos_usr_delete', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='relacaoservicos',
            name='usr_edicao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_relacaoservicos_usr_edicao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='relacaoservicos',
            name='usr_insercao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_relacaoservicos_usr_insercao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='filial',
            name='usr_delete',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_filial_usr_delete', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='filial',
            name='usr_edicao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_filial_usr_edicao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='filial',
            name='usr_insercao',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='filial_filial_usr_insercao', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterUniqueTogether(
            name='relacaoservicos',
            unique_together={('filial', 'servico')},
        ),
    ]
